#include <cvidef.h>

/*= D3371 Transmission Analyzer Include File ============================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __avd3371_HEADER
#define __avd3371_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)
#define VI_ERROR_INSTR_PARAMETER16              (_VI_ERROR+0x3FFC0810L)
#define VI_ERROR_INSTR_PARAMETER17              (_VI_ERROR+0x3FFC0811L)  
/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                           (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)

#define AVD3371_ERROR_INVALID_CONFIGURATION      (VI_ERROR_INSTR_OFFSET + 0xF0L)

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/

ViStatus _VI_FUNC avd3371_Initialize (ViRsrc resourceName, ViBoolean IDQuery,
                                       ViBoolean resetDevice,
                                       ViSession *instrumentHandle);

ViStatus CVIFUNC avd3371_Set_SSGModule (ViSession instrumentHandle,
                                        ViBoolean clockOutput,
                                        ViInt32 clockFrequency,
                                        ViBoolean clockReference);

ViStatus CVIFUNC avd3371_Set_PPG_PatternType (ViSession instrumentHandle,
                                              ViInt16 patternType,
                                              ViInt16 PRBSPatternLength,
                                              ViInt16 PRBSPatternMarkRatio,
                                              ViInt16 ZSUBPatternLength,
                                              ViInt16 ZSUBContinuousZeroLength,
                                              ViInt32 PROGPatternLength,
                                              ViInt32 startBit,
                                              ViString patternData,
                                              ViBoolean patternPolarity);

ViStatus CVIFUNC avd3371_AddErr_PPGPattern (ViSession instrumentHandle,
                                            ViBoolean addErrors,
                                            ViInt16 addErrorsMode,
                                            ViReal64 addErrosRate,
                                            ViInt16 addErrosRoute);

ViStatus CVIFUNC avd3371_Set_ClockDelay (ViSession instrumentHandle,
                                         ViInt16 clockDelay);

ViStatus CVIFUNC avd3371_Set_DataOutput (ViSession instrumentHandle,
                                         ViBoolean dataOutput,
                                         ViReal64 amplitude, ViInt16 offsetMode,
                                         ViReal64 offsetValue,
                                         ViInt16 crossPoint,
                                         ViInt16 terminationVoltage);

ViStatus CVIFUNC avd3371_Set_XDataOutput (ViSession instrumentHandle,
                                          ViBoolean tracking,
                                          ViBoolean xdataOutput,
                                          ViReal64 amplitude, ViInt16 offsetMode,
                                          ViReal64 offsetValue,
                                          ViInt16 crossPoint,
                                          ViInt16 terminationVoltage);

ViStatus CVIFUNC avd3371_Set_ClockOutput (ViSession instrumentHandle,
                                          ViBoolean clockOutput,
                                          ViReal64 amplitude, ViInt16 offsetMode,
                                          ViReal64 offsetValue,
                                          ViInt16 terminationVoltage);

ViStatus CVIFUNC avd3371_Set_XClockOutput (ViSession instrumentHandle,
                                           ViBoolean tracking,
                                           ViBoolean XClockOutput,
                                           ViReal64 amplitude,
                                           ViInt16 offsetMode,
                                           ViReal64 offsetValue,
                                           ViInt16 terminationVoltage);

ViStatus CVIFUNC avd3371_Set_BurstOutput (ViSession instrumentHandle,
                                          ViBoolean burstMode, ViBoolean source,
                                          ViInt32 burstCycle, ViInt32 offTime);

ViStatus CVIFUNC avd3371_Set_TriggerOutput (ViSession instrumentHandle,
                                            ViInt16 triggerSource,
                                            ViInt32 triggerPositiononPRBS,
                                            ViInt32 triggerPositononZSUB,
                                            ViInt32 triggerPositiononPROG);

ViStatus CVIFUNC avd3371_Set_ED_PatternType (ViSession instrumentHandle,
                                             ViBoolean tracking,
                                             ViInt16 patternType,
                                             ViInt16 PRBSPatternLength,
                                             ViInt16 PRBSPatternMarkRatio,
                                             ViInt16 ZSUBPatternLength,
                                             ViInt16 ZSUBContinuousZeroLength,
                                             ViInt32 PROGPatternLength,
                                             ViInt32 startBit,
                                             ViString patternData,
                                             ViBoolean patternPolarity);

ViStatus CVIFUNC avd3371_Set_Synchronization (ViSession instrumentHandle,
                                              ViInt16 autoSync,
                                              ViInt32 syncPatternAddressonPROG,
                                              ViInt16 syncPatternLengthonPROG,
                                              ViBoolean thresholdAutoSet,
                                              ViReal64 syncGainThresholdPRBS,
                                              ViReal64 syncLossThresholdPRBS,
                                              ViReal64 syncGainThresholdZSUBPROG,
                                              ViReal64 syncLossThresholdZSUBPROG);

ViStatus CVIFUNC avd3371_Set_ED_DataInput (ViSession instrumentHandle,
                                       	   ViBoolean dataPolarity,
                                           ViReal64 thresholdVoltage,
                                           ViInt16 terminationVoltage);

ViStatus CVIFUNC avd3371_Set_ED_ClockInput (ViSession instrumentHandle,
                                         	ViBoolean clockPolarity,
                                         	ViInt16 clockDelay,
                                         	ViInt16 terminationVoltage);

ViStatus CVIFUNC avd3371_Mask_MeasRoute (ViSession instrumentHandle,
                                         ViInt16 measurementRoute,
                                         ViBoolean mask);

ViStatus CVIFUNC avd3371_Set_AutoSearch (ViSession instrumentHandle,
                                         ViBoolean clockPolarityandDelay,
                                         ViBoolean thresholdVoltage,
                                         ViBoolean pattern);

ViStatus CVIFUNC avd3371_Set_LOGReport (ViSession instrumentHandle,
                                        ViBoolean basicMeasurementResults,
                                        ViBoolean syncandClockLossHistory,
                                        ViBoolean errorRateHistory,
                                        ViBoolean errorCountHistory,
                                        ViBoolean errorIntervalHistory,
                                        ViBoolean errorFreeIntervalHistory,
                                        ViBoolean frequencyHistory);

ViStatus CVIFUNC avd3371_Set_MeasCondition (ViSession instrumentHandle,
                                            ViInt16 measurementTimerMode,
                                            ViBoolean measurementInterval,
                                            ViInt16 measurementPeriodDay,
                                            ViInt16 measurementPeriodHour,
                                            ViInt16 measurementPeriodMinute,
                                            ViInt16 measurementPeriodSecond,
                                            ViBoolean burstMode,
                                            ViBoolean measureClockLossIntervals,
                                            ViBoolean measureSyncLossIntervals,
                                            ViBoolean errorRateThreshold,
                                            ViBoolean displayCurrentResults);

ViStatus CVIFUNC avd3371_Set_TriggerSource (ViSession instrumentHandle,
                                            ViInt16 triggerSource);

ViStatus CVIFUNC avd3371_Measurement (ViSession instrumentHandle,
                                      ViBoolean measurement);

ViStatus CVIFUNC avd3371_Exe_AutoSearch (ViSession instrumentHandle,
                                         ViBoolean autoSearch);

ViStatus CVIFUNC avd3371_DisplayFormat (ViSession instrumentHandle,
                                        ViBoolean bitCount, ViBoolean errorCount,
                                        ViBoolean immediateErrorCount,
                                        ViBoolean errorIntervals,
                                        ViBoolean errorFreeIntervals,
                                        ViBoolean thresholdEI,
                                        ViBoolean thresholdEFI,
                                        ViBoolean errorPerformance);

ViStatus CVIFUNC avd3371_Print (ViSession instrumentHandle);

ViStatus CVIFUNC avd3371_Load (ViSession instrumentHandle, ViInt16 load,
                               ViString fileName);

ViStatus CVIFUNC avd3371_Save (ViSession instrumentHandle, ViInt16 save,
                               ViString fileName);

ViStatus CVIFUNC avd3371_Beep (ViSession instrumentHandle, ViBoolean beepError,
                               ViBoolean beepAlarm);

ViStatus CVIFUNC avd3371_Set_DateTime (ViSession instrumentHandle, ViInt16 year,
                                       ViInt16 month, ViInt16 day, ViInt16 hour,
                                       ViInt16 minute);

ViStatus CVIFUNC avd3371_Set_StandardEventEnblRgstr (ViSession instrumentHandle,
                                                     ViInt32 registerValue);

ViStatus CVIFUNC avd3371_Read_StandardEvntRgstr (ViSession instrumentHandle,
                                                 ViInt32 *eventRegister);

ViStatus CVIFUNC avd3371_Set_ServiceReqEnblRgstr (ViSession instrumentHandle,
                                                  ViInt32 registerValue);

ViStatus CVIFUNC avd3371_Read_ServiceReqEnblRgstr (ViSession instrumentHandle,
                                                   ViInt32 *enableRegister);

ViStatus CVIFUNC avd3371_Read_STB (ViSession instrumentHandle,
                                   ViInt32 *eventRegister);

ViStatus CVIFUNC avd3371_Set_OperationEnblRgstr (ViSession instrumentHandle,
                                      	         ViInt32 registerValue);

ViStatus CVIFUNC avd3371_Wait (ViSession instrumentHandle);

ViStatus CVIFUNC avd3371_Clear_StatusBytes (ViSession instrumentHandle);

ViStatus CVIFUNC avd3371_Set_OperationTrnsFltr (ViSession instrumentHandle,
                                             	ViBoolean direction,
                                             	ViInt32 registerValue);

ViStatus CVIFUNC avd3371_Read_OperationEvntRgstr (ViSession instrumentHandle,
                                                  ViInt32 *eventRegister);

ViStatus CVIFUNC avd3371_Read_OperationCndRgstr (ViSession instrumentHandle,
                                                 ViInt32 *conditionRegister);

ViStatus CVIFUNC avd3371_Set_QuestionableEnblRgstr (ViSession instrumentHandle,
                                    	   	    	ViInt32 registerValue);

ViStatus CVIFUNC avd3371_Set_QuestionableTrnsFltr (ViSession instrumentHandle,
                                         		   ViBoolean direction,
                                              	   ViInt32 registerValue);

ViStatus CVIFUNC avd3371_Read_QuestionableEvntRgstr (ViSession instrumentHandle,
                                                     ViInt32 *eventRegister);

ViStatus CVIFUNC avd3371_Read_QuestionableCndRgstr (ViSession instrumentHandle,
                                                    ViInt32 *conditionRegister);

ViStatus CVIFUNC avd3371_Set_SettlingEnblRgstr (ViSession instrumentHandle,
                                     		    ViInt32 registerValue);

ViStatus CVIFUNC avd3371_Set_SettlingTrnsFltr (ViSession instrumentHandle,
                                     		   ViBoolean direction,
                                          	   ViInt32 registerValue);

ViStatus CVIFUNC avd3371_Read_SettlingEvntRgstr (ViSession instrumentHandle,
                                                 ViInt32 *eventRegister);

ViStatus CVIFUNC avd3371_Read_SettlingCndRgstr (ViSession instrumentHandle,
                                                ViInt32 *conditionRegister);

ViStatus CVIFUNC avd3371_Set_CLOSSEnblRgstr (ViSession instrumentHandle,
                                             ViInt32 registerValue);

ViStatus CVIFUNC avd3371_Set_CLOSSTrnsFltr (ViSession instrumentHandle,
                                            ViBoolean direction,
                                            ViInt32 registerValue);

ViStatus CVIFUNC avd3371_Read_CLOSSEvntRgstr (ViSession instrumentHandle,
                                              ViInt32 *eventRegister);

ViStatus CVIFUNC avd3371_Read_CLOSSCndRgstr (ViSession instrumentHandle,
                                             ViInt32 *conditionRegister);

ViStatus CVIFUNC avd3371_Read_DeviceEvntRgstr (ViSession instrumentHandle,
                                               ViInt32 *eventRegister);

ViStatus CVIFUNC avd3371_Init_StatusRegister (ViSession instrumentHandle);

ViStatus _VI_FUNC avd3371_OnOff_Outputs (ViSession instrumentHandle,
                                        ViBoolean outputs);

ViStatus _VI_FUNC avd3371_SingleErrorAddition (ViSession instrumentHandle);

ViStatus _VI_FUNC avd3371_ReSync (ViSession instrumentHandle);

ViStatus _VI_FUNC avd3371_ClearHistory (ViSession instrumentHandle);

ViStatus CVIFUNC avd3371_AutoSearchResult (ViSession instrumentHandle,
                                           ViInt16 *result);

ViStatus _VI_FUNC avd3371_AutoSearchData (ViSession instrumentHandle,
                                          ViChar inputPolarity[],
                                          ViReal64 *thresholdVoltage,
                                          ViInt16 *delay);

ViStatus CVIFUNC avd3371_BitCountFetchData (ViSession instrumentHandle,
                                            ViReal64 *totalBitCountEXP,
                                            ViInt32 *totalBitCountINT,
                                            ViReal64 *omittingBitCountEXP,
                                            ViInt32 *omittingBitCountINT,
                                            ViReal64 *insertingBitCountEXP,
                                            ViInt32 *insertingBitCountINT);

ViStatus CVIFUNC avd3371_BitCountCurrentData (ViSession instrumentHandle,
                                              ViReal64 *totalBitCountEXP,
                                              ViInt32 *totalBitCountINT,
                                              ViReal64 *omittingBitCountEXP,
                                              ViInt32 *omittingBitCountINT,
                                              ViReal64 *insertingBitCountEXP,
                                              ViInt32 *insertingBitCountINT);

ViStatus CVIFUNC avd3371_ErrorRateFetchData (ViSession instrumentHandle,
                                             ViReal64 *totalErrorRate,
                                             ViReal64 *omittingErrorRate,
                                             ViReal64 *insertingErrorRate);

ViStatus CVIFUNC avd3371_ErrorRateCurrData (ViSession instrumentHandle,
                                            ViReal64 *totalErrorRate,
                                            ViReal64 *omittingErrorRate,
                                            ViReal64 *insertingErrorRate);

ViStatus CVIFUNC avd3371_ErrorCountFetchData (ViSession instrumentHandle,
                                              ViReal64 *totalErrorCountEXP,
                                              ViInt32 *totalErrorCountINT,
                                              ViReal64 *omittingErrorCountEXP,
                                              ViInt32 *omittingErrorCountINT,
                                              ViReal64 *insertingErrorCountEXP,
                                              ViInt32 *insertingErrorCountINT);

ViStatus CVIFUNC avd3371_ErrorCountCurrData (ViSession instrumentHandle,
                                             ViReal64 *totalErrorCountEXP,
                                             ViInt32 *totalErrorCountINT,
                                             ViReal64 *omittingErrorCountEXP,
                                             ViInt32 *omittingErrorCountINT,
                                             ViReal64 *insertingErrorCountEXP,
                                             ViInt32 *insertingErrorCountINT);

ViStatus CVIFUNC avd3371_ImmErrorRateData (ViSession instrumentHandle,
                                           ViReal64 *totalErrorRate,
                                           ViReal64 *omittingErrorRate,
                                           ViReal64 *insertingErrorRate);

ViStatus CVIFUNC avd3371_ImmErrorCountData (ViSession instrumentHandle,
                                            ViReal64 *totalErrorCountEXP,
                                            ViInt32 *totalErrorCountINT,
                                            ViReal64 *omittingErrorCountEXP,
                                            ViInt32 *omittingErrorCountINT,
                                            ViReal64 *insertingErrorCountEXP,
                                            ViInt32 *insertingErrorCountINT);

ViStatus CVIFUNC avd3371_ErrorIntervalFetchData (ViSession instrumentHandle,
                                                 ViReal64 *totalErrorIntervalsPRC,
                                                 ViInt32 *totalErrorIntervalsINT,
                                                 ViReal64 *omittingErrorIntervalsPRC,
                                                 ViInt32 *omittingErrorIntervalsINT,
                                                 ViReal64 *insertingErrorIntervalsPRC,
                                                 ViInt32 *insertingErrorIntervalsINT);

ViStatus CVIFUNC avd3371_ErrorIntervalCurrData (ViSession instrumentHandle,
                                                ViReal64 *totalErrorIntervalsPRC,
                                                ViInt32 *totalErrorIntervalsINT,
                                                ViReal64 *omittingErrorIntervalsPRC,
                                                ViInt32 *omittingErrorIntervalsINT,
                                                ViReal64 *insertingErrorIntervalsPRC,
                                                ViInt32 *insertingErrorIntervalsINT);

ViStatus CVIFUNC avd3371_ErrFreeIntrvlFetchData (ViSession instrumentHandle,
                                                 ViReal64 *TTLErrorFreeIntervalsPRC,
                                                 ViInt32 *TTLErrorFreeIntervalsINT,
                                                 ViReal64 *OMTErrorFreeIntervalsPRC,
                                                 ViInt32 *OMTErrorFreeIntervalsINT,
                                                 ViReal64 *INSErrorFreeIntervalsPRC,
                                                 ViInt32 *INSErrorFreeIntervalsINT);

ViStatus CVIFUNC avd3371_ErrFreeIntrvlCurrData (ViSession instrumentHandle,
                                                ViReal64 *TTLErrorFreeIntervalsPRC,
                                                ViInt32 *TTLErrorFreeIntervalsINT,
                                                ViReal64 *OMTErrorFreeIntervalsPRC,
                                                ViInt32 *OMTErrorFreeIntervalsINT,
                                                ViReal64 *INSErrorFreeIntervalsPRC,
                                                ViInt32 *INSErrorFreeIntervalsINT);

ViStatus CVIFUNC avd3371_FreqFetchData (ViSession instrumentHandle,
                                        ViReal64 *frequency);

ViStatus CVIFUNC avd3371_FreqCurrData (ViSession instrumentHandle,
                                       ViReal64 *frequency);

ViStatus CVIFUNC avd3371_ClockLossFetchData (ViSession instrumentHandle,
                                             ViInt32 *clockLossIntervals);

ViStatus CVIFUNC avd3371_ClockLossCurrData (ViSession instrumentHandle,
                                            ViInt32 *clockLossIntervals);

ViStatus CVIFUNC avd3371_SyncLossFetchData (ViSession instrumentHandle,
                                            ViInt32 *syncLossIntervals);

ViStatus CVIFUNC avd3371_SyncLossCurrData (ViSession instrumentHandle,
                                           ViInt32 *syncLossIntervals);

ViStatus CVIFUNC avd3371_ThresholdEIFetchData (ViSession instrumentHandle,
                                               ViInt16 thresholdCondition,
                                               ViReal64 *thresholdEIPRC,
                                               ViInt32 *thresholdEIINT);

ViStatus CVIFUNC avd3371_ThresholdEICurrData (ViSession instrumentHandle,
                                              ViInt16 thresholdCondition,
                                              ViReal64 *thresholdEIPRC,
                                              ViInt32 *thresholdEIINT);

ViStatus CVIFUNC avd3371_ThresholdEFIFetchData (ViSession instrumentHandle,
                                                ViInt16 thresholdCondition,
                                                ViReal64 *thresholdEFIPRC,
                                                ViInt32 *thresholdEFIINT);

ViStatus CVIFUNC avd3371_ThresholdEFICurrData (ViSession instrumentHandle,
                                               ViInt16 thresholdCondition,
                                               ViReal64 *thresholdEFIPRC,
                                               ViInt32 *thresholdEFIINT);

ViStatus CVIFUNC avd3371_ErrorPrfrmFetchData (ViSession instrumentHandle,
                                              ViReal64 *errorSecondsPRC,
                                              ViInt32 *errorSecondsINT,
                                              ViReal64 *errorFreeSecondsPRC,
                                              ViInt32 *errorFreeSecondsINT,
                                              ViReal64 *severelyErroredSecondsPRC,
                                              ViInt32 *severelyErroredsecondsINT,
                                              ViReal64 *unavailableSecondsPRC,
                                              ViInt32 *unavailableSecondINT,
                                              ViReal64 *degradedMinutesPRC,
                                              ViInt32 *degratedMinutesINT);

ViStatus CVIFUNC avd3371_ErrorPrfrmCurrData (ViSession instrumentHandle,
                                             ViReal64 *errorSecondsPRC,
                                             ViInt32 *errorSecondsINT,
                                             ViReal64 *errorFreeSecondsPRC,
                                             ViInt32 *errorFreeSecondsINT,
                                             ViReal64 *severelyErroredSecondsPRC,
                                             ViInt32 *severelyErroredsecondsINT,
                                             ViReal64 *unavailableSecondsPRC,
                                             ViInt32 *unavailableSecondINT,
                                             ViReal64 *degradedMinutesPRC,
                                             ViInt32 *degratedMinutesINT);

ViStatus CVIFUNC avd3371_MeasPassageTime (ViSession instrumentHandle,
                                          ViInt16 *day, ViInt16 *hour,
                                          ViInt16 *minute, ViInt16 *second);

ViStatus CVIFUNC avd3371_MeasRemainedTime (ViSession instrumentHandle,
                                           ViInt16 *day, ViInt16 *hour,
                                           ViInt16 *minute, ViInt16 *second);

ViStatus CVIFUNC avd3371_MeasStartTime (ViSession instrumentHandle,
                                        ViInt16 *year, ViInt16 *month,
                                        ViInt16 *day, ViInt16 *hour,
                                        ViInt16 *minute, ViInt16 *second);

ViStatus CVIFUNC avd3371_PresentTime (ViSession instrumentHandle, ViInt16 *year,
                                      ViInt16 *month, ViInt16 *day,
                                      ViInt16 *hour, ViInt16 *minute,
                                      ViInt16 *second);

ViStatus CVIFUNC avd3371_MntrSttRealData (ViSession instrumentHandle,
                                          ViBoolean *dataError,
                                          ViBoolean *clockLoss,
                                          ViBoolean *syncLoss);

ViStatus CVIFUNC avd3371_MntrSttHistData (ViSession instrumentHandle,
                                          ViBoolean *dataError,
                                          ViBoolean *clockLoss,
                                          ViBoolean *syncLoss);

ViStatus _VI_FUNC avd3371_Reset (ViSession instrumentHandle);

ViStatus _VI_FUNC avd3371_ErrorMessage (ViSession instrumentHandle,
                                         ViStatus statusCode, ViChar message[]);

ViStatus _VI_FUNC avd3371_Query_TypeRevision (ViSession instrumentHandle,
                                               ViChar instrumentDriverRevision[],
                                               ViChar firmwareType[],
                                               ViChar firmwareSystemCode[],
                                               ViChar firmwareRevision[]);

ViStatus CVIFUNC avd3371_close (ViSession instrSession);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
